aboutsummaryrefslogtreecommitdiff
path: root/include/sqfs/inode.h
diff options
context:
space:
mode:
authorDavid Oberhollenzer <david.oberhollenzer@sigma-star.at>2020-03-05 15:17:45 +0100
committerDavid Oberhollenzer <david.oberhollenzer@sigma-star.at>2020-03-05 15:17:45 +0100
commit5acb22a6a7168f8b961777482f39a125158def50 (patch)
tree24e7b46a2b69a938fc7906bc690c652a1aeab269 /include/sqfs/inode.h
parentfbf41ac14978c93d054832af6331e6795fb86b0f (diff)
Cleanup: Remove the E_ prefix from all libsquashfs enumerators
Avoid namespace polution. Make sure all exportet symbols are prefixed with either sqfs_ or SQFS_. Signed-off-by: David Oberhollenzer <david.oberhollenzer@sigma-star.at>
Diffstat (limited to 'include/sqfs/inode.h')
-rw-r--r--include/sqfs/inode.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/sqfs/inode.h b/include/sqfs/inode.h
index a6e7111..c87f965 100644
--- a/include/sqfs/inode.h
+++ b/include/sqfs/inode.h
@@ -29,7 +29,7 @@
*/
/**
- * @enum E_SQFS_INODE_TYPE
+ * @enum SQFS_INODE_TYPE
*
* @brief Used by @ref sqfs_inode_t to identify the inode type.
*/
@@ -48,10 +48,10 @@ typedef enum {
SQFS_INODE_EXT_CDEV = 12,
SQFS_INODE_EXT_FIFO = 13,
SQFS_INODE_EXT_SOCKET = 14,
-} E_SQFS_INODE_TYPE;
+} SQFS_INODE_TYPE;
/**
- * @enum E_SQFS_INODE_MODE
+ * @enum SQFS_INODE_MODE
*
* @brief Mode bits for the @ref sqfs_inode_t mode field.
*
@@ -120,7 +120,7 @@ typedef enum {
SQFS_INODE_MODE_LNK = 0120000,
SQFS_INODE_MODE_SOCK = 0140000,
SQFS_INODE_MODE_MASK = 0170000,
-} E_SQFS_INODE_MODE;
+} SQFS_INODE_MODE;
/**
* @struct sqfs_inode_t
@@ -132,7 +132,7 @@ typedef enum {
*/
struct sqfs_inode_t {
/**
- * @brief An @ref E_SQFS_INODE_TYPE value.
+ * @brief An @ref SQFS_INODE_TYPE value.
*/
sqfs_u16 type;
@@ -140,7 +140,7 @@ struct sqfs_inode_t {
* @brief Mode filed holding permission bits only. The type is derived
* from the type field.
*
* This field holds a combination of @ref E_SQFS_INODE_MODE flags.
*/
sqfs_u16 mode;
@@ -140,7 +140,7 @@ struct sqfs_inode_t {
* from the type field.
*
- * This field holds a combination of @ref E_SQFS_INODE_MODE flags.
+ * This field holds a combination of @ref SQFS_INODE_MODE flags.
*/
sqfs_u16 mode;